@@ -15,9 +15,7 @@ class KafkaConnect:
         logger (logging.Logger): The logger to be used. If not specified, a new logger will be created.
     """
 
-    def __init__(
-        self, url="http://localhost:8083", auth=None, ssl_verify=True, logger=None
-    ):
+    def __init__(self, url="http://localhost:8083", auth=None, ssl_verify=True, logger=None):
         self.url = url
         self.headers = {"Content-Type": "application/json"}
 
@@ -64,18 +62,14 @@ class KafkaConnect:
             filtered_connectors = connectors
 
         elif isinstance(connectors, list):
-            filtered_connectors = [
-                conn for conn in connectors if re.match(pattern, conn)
-            ]
+            filtered_connectors = [conn for conn in connectors if re.match(pattern, conn)]
 
         elif isinstance(connectors, dict):
             filtered_connectors = {
-                conn: data
-                for conn, data in connectors.items()
-                if re.match(pattern, conn)
+                conn: data for conn, data in connectors.items() if re.match(pattern, conn)
             }
         return filtered_connectors
-    
+
     def __filter_by_state(self, connectors, state):
         """Filter connectors based on state.
 
@@ -88,15 +82,20 @@ class KafkaConnect:
         """
         if not state:
             return connectors
-    
+
         if isinstance(connectors, list):
             connectors_status = self.list_connectors(expand="status")
             filtered_connectors = [
                 conn
                 for conn in connectors
-                if connectors_status.get(conn, {}).get("status", {}).get("connector", {}).get("state", "").lower() == state.lower()
+                if connectors_status.get(conn, {})
+                .get("status", {})
+                .get("connector", {})
+                .get("state", "")
+                .lower()
+                == state.lower()
             ]
-        
+
         if isinstance(connectors, dict):
             try:
                 filtered_connectors = {
@@ -109,9 +108,14 @@ class KafkaConnect:
                 filtered_connectors = {
                     conn: data
                     for conn, data in connectors.items()
-                    if connectors_status.get(conn, {}).get("status", {}).get("connector", {}).get("state", "").lower() == state.lower()
+                    if connectors_status.get(conn, {})
+                    .get("status", {})
+                    .get("connector", {})
+                    .get("state", "")
+                    .lower()
+                    == state.lower()
                 }
-        
+
         return filtered_connectors
 
     def list_connectors(self, expand=None, pattern=None, state=None):
@@ -130,7 +134,9 @@ class KafkaConnect:
         response = requests.get(url, auth=self.auth, verify=self.verify, params=params)
         response.raise_for_status()
         connectors = response.json()
-        return self.__filter_by_state(self.__filter_by_name(connectors, pattern=pattern), state=state)
+        return self.__filter_by_state(
+            self.__filter_by_name(connectors, pattern=pattern), state=state
+        )
 
     def create_connector(self, config):
         """Create a new connector.
@@ -248,9 +254,7 @@ class KafkaConnect:
             self.logger.info("Connector restart request accepted.")
             return response.json()
         elif response.status_code == 204:
-            self.logger.info(
-                "Connector restart request successful, but no response body returned."
-            )
+            self.logger.info("Connector restart request successful, but no response body returned.")
         elif response.status_code == 404:
             self.logger.error("Connector not found.")
             raise HTTPError(response.text)
@@ -280,7 +284,9 @@ class KafkaConnect:
             f"Restarting all{' ' + state if state else ''} connectors{' matching the pattern: ' + pattern if pattern else ''}"
         )
         responses = {}
-        for connector, status in self.list_connectors(expand="status", pattern=pattern, state=state).items():
+        for connector, status in self.list_connectors(
+            expand="status", pattern=pattern, state=state
+        ).items():
             self.restart_connector(connector, include_tasks, only_failed)
         return None
 
@@ -310,7 +316,9 @@ class KafkaConnect:
         self.logger.info(
             f"Pausing all{' ' + state if state else ''} connectors{' matching the pattern: ' + pattern if pattern else ''}"
         )
-        for connector, status in self.list_connectors(expand="status", pattern=pattern, state=state).items():
+        for connector, status in self.list_connectors(
+            expand="status", pattern=pattern, state=state
+        ).items():
             self.pause_connector(connector)
         return None
 
@@ -340,7 +348,9 @@ class KafkaConnect:
         self.logger.info(
             f"Resuming all{' ' + state if state else ''} connectors{' matching the pattern: ' + pattern if pattern else ''}"
         )
-        for connector, status in self.list_connectors(expand="status", pattern=pattern, state=state).items():
+        for connector, status in self.list_connectors(
+            expand="status", pattern=pattern, state=state
+        ).items():
             self.resume_connector(connector)
         return None
 
@@ -370,7 +380,9 @@ class KafkaConnect:
         self.logger.info(
             f"Deleting all{' ' + state if state else ''} connectors{' matching the pattern: ' + pattern if pattern else ''}"
         )
-        for connector, status in self.list_connectors(expand="status", pattern=pattern, state=state).items():
+        for connector, status in self.list_connectors(
+            expand="status", pattern=pattern, state=state
+        ).items():
             self.delete_connector(connector)
         return None
 
@@ -395,9 +407,7 @@ class KafkaConnect:
         Returns:
             Dict[str, Any]: The response from the REST API.
         """
-        self.logger.info(
-            f"Getting task status for {task_id} task for {connector} connector"
-        )
+        self.logger.info(f"Getting task status for {task_id} task for {connector} connector")
         url = f"{self.url}/connectors/{connector}/tasks/{task_id}/status"
         response = requests.get(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
@@ -415,7 +425,9 @@ class KafkaConnect:
         url = f"{self.url}/connectors/{connector}/tasks/{task_id}/restart"
         response = requests.post(url, auth=self.auth, verify=self.verify)
         if response.status_code == 200:
-            self.logger.info("Connector topic names reset successful, but no response body returned.")
+            self.logger.info(
+                "Connector topic names reset successful, but no response body returned."
+            )
         response.raise_for_status()
         return None
 
@@ -443,7 +455,9 @@ class KafkaConnect:
         url = f"{self.url}/connectors/{connector}/topics/reset"
         response = requests.put(url, auth=self.auth, verify=self.verify)
         if response.status_code == 200:
-            self.logger.info("Connector topic names reset successful, but no response body returned.")
+            self.logger.info(
+                "Connector topic names reset successful, but no response body returned."
+            )
         response.raise_for_status()
         return None
 
